@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from .literals import (
     CodeType,
@@ -40,10 +40,17 @@ __all__ = (
     "AssetDetailsTypeDef",
     "AssetEntryTypeDef",
     "AssetSourceEntryTypeDef",
+    "CancelJobRequestRequestTypeDef",
+    "CreateDataSetRequestRequestTypeDef",
     "CreateDataSetResponseTypeDef",
+    "CreateJobRequestRequestTypeDef",
     "CreateJobResponseTypeDef",
+    "CreateRevisionRequestRequestTypeDef",
     "CreateRevisionResponseTypeDef",
     "DataSetEntryTypeDef",
+    "DeleteAssetRequestRequestTypeDef",
+    "DeleteDataSetRequestRequestTypeDef",
+    "DeleteRevisionRequestRequestTypeDef",
     "DetailsTypeDef",
     "ExportAssetToSignedUrlRequestDetailsTypeDef",
     "ExportAssetToSignedUrlResponseDetailsTypeDef",
@@ -52,9 +59,13 @@ __all__ = (
     "ExportRevisionsToS3RequestDetailsTypeDef",
     "ExportRevisionsToS3ResponseDetailsTypeDef",
     "ExportServerSideEncryptionTypeDef",
+    "GetAssetRequestRequestTypeDef",
     "GetAssetResponseTypeDef",
+    "GetDataSetRequestRequestTypeDef",
     "GetDataSetResponseTypeDef",
+    "GetJobRequestRequestTypeDef",
     "GetJobResponseTypeDef",
+    "GetRevisionRequestRequestTypeDef",
     "GetRevisionResponseTypeDef",
     "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
     "ImportAssetFromSignedUrlRequestDetailsTypeDef",
@@ -63,20 +74,32 @@ __all__ = (
     "ImportAssetsFromS3ResponseDetailsTypeDef",
     "JobEntryTypeDef",
     "JobErrorTypeDef",
+    "ListDataSetRevisionsRequestRequestTypeDef",
     "ListDataSetRevisionsResponseTypeDef",
+    "ListDataSetsRequestRequestTypeDef",
     "ListDataSetsResponseTypeDef",
+    "ListJobsRequestRequestTypeDef",
     "ListJobsResponseTypeDef",
+    "ListRevisionAssetsRequestRequestTypeDef",
     "ListRevisionAssetsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "OriginDetailsTypeDef",
     "PaginatorConfigTypeDef",
     "RequestDetailsTypeDef",
     "ResponseDetailsTypeDef",
+    "ResponseMetadataTypeDef",
     "RevisionDestinationEntryTypeDef",
     "RevisionEntryTypeDef",
     "S3SnapshotAssetTypeDef",
+    "StartJobRequestRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateAssetRequestRequestTypeDef",
     "UpdateAssetResponseTypeDef",
+    "UpdateDataSetRequestRequestTypeDef",
     "UpdateDataSetResponseTypeDef",
+    "UpdateRevisionRequestRequestTypeDef",
     "UpdateRevisionResponseTypeDef",
 )
 
@@ -145,6 +168,36 @@ AssetSourceEntryTypeDef = TypedDict(
     },
 )
 
+CancelJobRequestRequestTypeDef = TypedDict(
+    "CancelJobRequestRequestTypeDef",
+    {
+        "JobId": str,
+    },
+)
+
+_RequiredCreateDataSetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDataSetRequestRequestTypeDef",
+    {
+        "AssetType": Literal["S3_SNAPSHOT"],
+        "Description": str,
+        "Name": str,
+    },
+)
+_OptionalCreateDataSetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDataSetRequestRequestTypeDef",
+    {
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateDataSetRequestRequestTypeDef(
+    _RequiredCreateDataSetRequestRequestTypeDef, _OptionalCreateDataSetRequestRequestTypeDef
+):
+    pass
+
+
 CreateDataSetResponseTypeDef = TypedDict(
     "CreateDataSetResponseTypeDef",
     {
@@ -159,8 +212,16 @@ CreateDataSetResponseTypeDef = TypedDict(
         "SourceId": str,
         "Tags": Dict[str, str],
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateJobRequestRequestTypeDef = TypedDict(
+    "CreateJobRequestRequestTypeDef",
+    {
+        "Details": "RequestDetailsTypeDef",
+        "Type": TypeType,
     },
-    total=False,
 )
 
 CreateJobResponseTypeDef = TypedDict(
@@ -174,10 +235,32 @@ CreateJobResponseTypeDef = TypedDict(
         "State": StateType,
         "Type": TypeType,
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateRevisionRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateRevisionRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+    },
+)
+_OptionalCreateRevisionRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateRevisionRequestRequestTypeDef",
+    {
+        "Comment": str,
+        "Tags": Dict[str, str],
     },
     total=False,
 )
 
+
+class CreateRevisionRequestRequestTypeDef(
+    _RequiredCreateRevisionRequestRequestTypeDef, _OptionalCreateRevisionRequestRequestTypeDef
+):
+    pass
+
+
 CreateRevisionResponseTypeDef = TypedDict(
     "CreateRevisionResponseTypeDef",
     {
@@ -190,8 +273,8 @@ CreateRevisionResponseTypeDef = TypedDict(
         "SourceId": str,
         "Tags": Dict[str, str],
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredDataSetEntryTypeDef = TypedDict(
@@ -221,6 +304,30 @@ class DataSetEntryTypeDef(_RequiredDataSetEntryTypeDef, _OptionalDataSetEntryTyp
     pass
 
 
+DeleteAssetRequestRequestTypeDef = TypedDict(
+    "DeleteAssetRequestRequestTypeDef",
+    {
+        "AssetId": str,
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+
+DeleteDataSetRequestRequestTypeDef = TypedDict(
+    "DeleteDataSetRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+    },
+)
+
+DeleteRevisionRequestRequestTypeDef = TypedDict(
+    "DeleteRevisionRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+
 DetailsTypeDef = TypedDict(
     "DetailsTypeDef",
     {
@@ -377,6 +484,15 @@ class ExportServerSideEncryptionTypeDef(
     pass
 
 
+GetAssetRequestRequestTypeDef = TypedDict(
+    "GetAssetRequestRequestTypeDef",
+    {
+        "AssetId": str,
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+
 GetAssetResponseTypeDef = TypedDict(
     "GetAssetResponseTypeDef",
     {
@@ -390,8 +506,15 @@ GetAssetResponseTypeDef = TypedDict(
         "RevisionId": str,
         "SourceId": str,
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetDataSetRequestRequestTypeDef = TypedDict(
+    "GetDataSetRequestRequestTypeDef",
+    {
+        "DataSetId": str,
     },
-    total=False,
 )
 
 GetDataSetResponseTypeDef = TypedDict(
@@ -408,8 +531,15 @@ GetDataSetResponseTypeDef = TypedDict(
         "SourceId": str,
         "Tags": Dict[str, str],
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetJobRequestRequestTypeDef = TypedDict(
+    "GetJobRequestRequestTypeDef",
+    {
+        "JobId": str,
     },
-    total=False,
 )
 
 GetJobResponseTypeDef = TypedDict(
@@ -423,8 +553,16 @@ GetJobResponseTypeDef = TypedDict(
         "State": StateType,
         "Type": TypeType,
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetRevisionRequestRequestTypeDef = TypedDict(
+    "GetRevisionRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+        "RevisionId": str,
     },
-    total=False,
 )
 
 GetRevisionResponseTypeDef = TypedDict(
@@ -439,8 +577,8 @@ GetRevisionResponseTypeDef = TypedDict(
         "SourceId": str,
         "Tags": Dict[str, str],
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ImportAssetFromSignedUrlJobErrorDetailsTypeDef = TypedDict(
@@ -553,11 +691,44 @@ class JobErrorTypeDef(_RequiredJobErrorTypeDef, _OptionalJobErrorTypeDef):
     pass
 
 
+_RequiredListDataSetRevisionsRequestRequestTypeDef = TypedDict(
+    "_RequiredListDataSetRevisionsRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+    },
+)
+_OptionalListDataSetRevisionsRequestRequestTypeDef = TypedDict(
+    "_OptionalListDataSetRevisionsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListDataSetRevisionsRequestRequestTypeDef(
+    _RequiredListDataSetRevisionsRequestRequestTypeDef,
+    _OptionalListDataSetRevisionsRequestRequestTypeDef,
+):
+    pass
+
+
 ListDataSetRevisionsResponseTypeDef = TypedDict(
     "ListDataSetRevisionsResponseTypeDef",
     {
         "NextToken": str,
         "Revisions": List["RevisionEntryTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListDataSetsRequestRequestTypeDef = TypedDict(
+    "ListDataSetsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "Origin": str,
     },
     total=False,
 )
@@ -567,6 +738,17 @@ ListDataSetsResponseTypeDef = TypedDict(
     {
         "DataSets": List["DataSetEntryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListJobsRequestRequestTypeDef = TypedDict(
+    "ListJobsRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "RevisionId": str,
     },
     total=False,
 )
@@ -576,25 +758,56 @@ ListJobsResponseTypeDef = TypedDict(
     {
         "Jobs": List["JobEntryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListRevisionAssetsRequestRequestTypeDef = TypedDict(
+    "_RequiredListRevisionAssetsRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+_OptionalListRevisionAssetsRequestRequestTypeDef = TypedDict(
+    "_OptionalListRevisionAssetsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
     },
     total=False,
 )
 
+
+class ListRevisionAssetsRequestRequestTypeDef(
+    _RequiredListRevisionAssetsRequestRequestTypeDef,
+    _OptionalListRevisionAssetsRequestRequestTypeDef,
+):
+    pass
+
+
 ListRevisionAssetsResponseTypeDef = TypedDict(
     "ListRevisionAssetsResponseTypeDef",
     {
         "Assets": List["AssetEntryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
     },
-    total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 OriginDetailsTypeDef = TypedDict(
@@ -638,6 +851,17 @@ ResponseDetailsTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredRevisionDestinationEntryTypeDef = TypedDict(
     "_RequiredRevisionDestinationEntryTypeDef",
     {
@@ -692,6 +916,39 @@ S3SnapshotAssetTypeDef = TypedDict(
     },
 )
 
+StartJobRequestRequestTypeDef = TypedDict(
+    "StartJobRequestRequestTypeDef",
+    {
+        "JobId": str,
+    },
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": Dict[str, str],
+    },
+)
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": List[str],
+    },
+)
+
+UpdateAssetRequestRequestTypeDef = TypedDict(
+    "UpdateAssetRequestRequestTypeDef",
+    {
+        "AssetId": str,
+        "DataSetId": str,
+        "Name": str,
+        "RevisionId": str,
+    },
+)
+
 UpdateAssetResponseTypeDef = TypedDict(
     "UpdateAssetResponseTypeDef",
     {
@@ -705,10 +962,32 @@ UpdateAssetResponseTypeDef = TypedDict(
         "RevisionId": str,
         "SourceId": str,
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateDataSetRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateDataSetRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+    },
+)
+_OptionalUpdateDataSetRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateDataSetRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Name": str,
     },
     total=False,
 )
 
+
+class UpdateDataSetRequestRequestTypeDef(
+    _RequiredUpdateDataSetRequestRequestTypeDef, _OptionalUpdateDataSetRequestRequestTypeDef
+):
+    pass
+
+
 UpdateDataSetResponseTypeDef = TypedDict(
     "UpdateDataSetResponseTypeDef",
     {
@@ -722,10 +1001,33 @@ UpdateDataSetResponseTypeDef = TypedDict(
         "OriginDetails": "OriginDetailsTypeDef",
         "SourceId": str,
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateRevisionRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateRevisionRequestRequestTypeDef",
+    {
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+_OptionalUpdateRevisionRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateRevisionRequestRequestTypeDef",
+    {
+        "Comment": str,
+        "Finalized": bool,
     },
     total=False,
 )
 
+
+class UpdateRevisionRequestRequestTypeDef(
+    _RequiredUpdateRevisionRequestRequestTypeDef, _OptionalUpdateRevisionRequestRequestTypeDef
+):
+    pass
+
+
 UpdateRevisionResponseTypeDef = TypedDict(
     "UpdateRevisionResponseTypeDef",
     {
@@ -737,6 +1039,6 @@ UpdateRevisionResponseTypeDef = TypedDict(
         "Id": str,
         "SourceId": str,
         "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
